from setuptools import setup

setup(name='nit-distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['nit-distributions'],
      author = 'Nitin Bhandari',
      zip_safe=False)
